==> Zephyrus-3.3.2.11629.tar.gz: Zephyrus-3.3.2.11629/Zephyrus/comment/migrations/0012_auto_20190602_0421.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('comment', '0011_auto_20190529_1510'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='comment',
            options={'verbose_name': 'Comment', 'verbose_name_plural': 'Comments'},
        ),
        migrations.AddField(
            model_name='comment',
            name='facebookMsgId',
            field=models.CharField(verbose_name='Facebook comment Id', max_length=400, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='comment',
            name='createDate',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Create date'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='display',
            field=models.BooleanField(default=True, verbose_name='Display'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='email',
            field=models.EmailField(max_length=254, null=True, verbose_name='Email', blank=True),
        ),
        migrations.AlterField(
            model_name='comment',
            name='facebook',
            field=models.BooleanField(default=False, verbose_name='Is Facebook comment plugin'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='facebookUser',
            field=models.CharField(verbose_name='Facebook user', max_length=128, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='comment',
            name='message',
            field=models.TextField(verbose_name='Message'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='url',
            field=models.CharField(verbose_name='URL', max_length=400, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='comment',
            name='user',
            field=models.ForeignKey(verbose_name='User', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
    ]

==> Zephyrus-4.1.10.13272.tar.gz: Zephyrus-4.1.10.13272/Zephyrus/comment/migrations/0012_auto_20190602_0421.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('comment', '0011_auto_20190529_1510'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='comment',
            options={'verbose_name': 'Comment', 'verbose_name_plural': 'Comments'},
        ),
        migrations.AddField(
            model_name='comment',
            name='facebookMsgId',
            field=models.CharField(verbose_name='Facebook comment Id', max_length=400, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='comment',
            name='createDate',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Create date'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='display',
            field=models.BooleanField(default=True, verbose_name='Display'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='email',
            field=models.EmailField(max_length=254, null=True, verbose_name='Email', blank=True),
        ),
        migrations.AlterField(
            model_name='comment',
            name='facebook',
            field=models.BooleanField(default=False, verbose_name='Is Facebook comment plugin'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='facebookUser',
            field=models.CharField(verbose_name='Facebook user', max_length=128, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='comment',
            name='message',
            field=models.TextField(verbose_name='Message'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='url',
            field=models.CharField(verbose_name='URL', max_length=400, null=True, editable=False),
        ),
        migrations.AlterField(
            model_name='comment',
            name='user',
            field=models.ForeignKey(verbose_name='User', blank=True, to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE),
        ),
    ]
